# Importing required modules
from requests import get , post
endpoint = 'https://www.edbl.xyz/api/{}'

# Defining the needed exceptions
class IdNotGiven(Exception):
	pass

class TokenNotGiven(Exception):
	pass

class InvalidParam(Exception):
	pass
# The bot class
class Bot:
	def __init__(self, id:int=None , token:str=None):
		self.id = id
		self.token = token
	def get_info(self):
		if self.id == None:
			raise IdNotGiven('Bot id must be given in the class params')
		return get(endpoint.format(f"bots/{self.id}")).json()
	def post_status(self , user_count:int=None , server_count:int=None):
		if self.token == None:
			raise TokenNotGiven('User token must be given in the class params to use this method')
		if user_count==None or server_count==None:
			raise InvalidParam('User count or/and server count is required to post status')
		return post(url=endpoint.format("postStatus"),json={'token' : self.token , 'serversCount' : server_count , 'usersCount' : user_count}).json()
# Example
"""
mika = Bot(631669116926820353)
print(mika.get_info())
"""



# Importing required modules
from requests import get
endpoint = 'https://www.edbl.xyz/api/user/{}'

# Defining the IdNotGiven exception
class IdNotGiven(Exception):
	pass

# The user class
class User:
	def __init__(self,id:int=None):
		self.id = id
	def get_info(self):
		if self.id == None:
			raise IdNotGiven('User id must be given in the class params')
		return get(endpoint.format(self.id)).json()

# Example
"""
jake = User(480407581085532180)
print(jake.get_info())
"""


import setuptools
from distutils.core import setup
with open("README.md", "r") as rm:
  long_description = rm.read()
setup(
  name = 'edblpy',        
  packages = ['edblpy'],   
  version = '1.4.0',   
  license='MIT', 
  description = 'A simple and easy-to-use unofficial python wrapper around the Electro discord bot list api',   
  long_description= long_description,
  long_description_content_type='text/markdown',
  author = 'Jake', 
  author_email = 'jstyle07072004@gmail.com', 
  url = 'https://github.com/Jakeisbored/edblpy',  
  download_url = 'https://github.com/Jakeisbored/edblpy',
  keywords = ['edbl', 'discord', 'botlist'],   
  install_requires=[
          'requests'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Developers',  
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',     
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)